Index: /trunk/src/VBox/Additions/linux/drm/vbox_drv.h
===================================================================
--- /trunk/src/VBox/Additions/linux/drm/vbox_drv.h	(revision 52611)
+++ /trunk/src/VBox/Additions/linux/drm/vbox_drv.h	(revision 52612)
@@ -122,6 +122,8 @@
 {
     struct drm_connector base;
-    /** Property for receiving mode hints from user space. */
-    struct drm_property *pModeHintProp;
+    char szName[32];
+    /** Device attribute for sysfs file used for receiving mode hints from user
+     * space. */
+    struct device_attribute deviceAttribute;
     struct
     {
